# libpythonpro
Módulo para exemplificar construcao de projetos Python no curso PyTools

Nesse curso é ensinado como contribuir  com projetos de código aberto

Link para o curso [Python Pro](https://www.python.pro.br/)

[![Updates](https://pyup.io/repos/github/rwollensc/libpythonpro/shield.svg)](https://pyup.io/repos/github/rwollensc/libpythonpro/)
[![Python 3](https://pyup.io/repos/github/rwollensc/libpythonpro/python-3-shield.svg)](https://pyup.io/repos/github/rwollensc/libpythonpro/)


Suportada versao 3 de Python

Para instalar
```console
python3 -m venv .venv
.venv/Scripts/activate
pip install -r requirements-dev.txt
```
Para conferir qualidade de código:
```console
flake8
```

Tópicos a serem abordados:

1. Git
2. Virtualenv
3. Pip